pySMART.smartx
========================

It's a fork of pySMART with lots of bug fix and enhances.


You can follow the [original-readme](./README_ORIGINAL.rst) to read the doc and checkout the way to use it.

More doc about our fixes and enhance may be add if we have more free time.

Pull request is very welcome!

# Feature
+ Python2/Python3 compatible.
+ Bug fixes.
+ More device-type supports.
  + Output parse intel ssd
  + Some seagate hdd's self_test support
+ Health status API.
+ Support for MacOS

# Quick start

just run `pip install pysmart.smartx` to install this package.

# ChangeLog

+ 2019-05-31: Add temperature attribute on `Device` object 
+ 2018-03-01: Upload a new version with stdout-encoding fix by DPSB

